"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.writeManifest = exports.login = exports.push = void 0;
const child_process_1 = require("child_process");
const fs_extra_1 = require("fs-extra");
const js_yaml_1 = require("js-yaml");
function push(context, options, manifestPath) {
    return __awaiter(this, void 0, void 0, function* () {
        const command = 'cf';
        const params = ['push', `-f=${manifestPath}`];
        if (options.randomRoute) {
            params.push('--random-route');
        }
        context.logger.info(`🚀 Push ${context.target.project} to Cloud Foundry`);
        yield spawnProcess(command, params);
    });
}
exports.push = push;
function login(context, options) {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            const command = 'cf';
            const params = ['target'];
            yield spawnProcess(command, params);
        }
        catch (err) {
            const command = 'cf';
            const params = ['login'];
            if (options.sso) {
                params.push('--sso');
            }
            if (options.skipSslValidation) {
                params.push('--skip-ssl-validation');
            }
            context.logger.info(`🔑 You are not authenticated for Cloud Foundry! Let's login first.`);
            yield spawnProcess(command, params);
        }
    });
}
exports.login = login;
function writeManifest(context, path) {
    return __awaiter(this, void 0, void 0, function* () {
        const manifestJson = {
            applications: [
                {
                    name: context.target.project,
                    path: '.',
                    instances: 1,
                    memory: '64M',
                    disk_quota: '250M',
                    buildpacks: ['staticfile_buildpack']
                }
            ]
        };
        yield fs_extra_1.writeFile(path, js_yaml_1.safeDump(manifestJson));
    });
}
exports.writeManifest = writeManifest;
function spawnProcess(command, parameters) {
    return __awaiter(this, void 0, void 0, function* () {
        return new Promise((resolve, reject) => {
            const proc = child_process_1.spawn(command, parameters, { cwd: process.cwd(), stdio: 'inherit' });
            proc.on('close', code => {
                code === 0 ? resolve() : reject(new Error(`process '${command}' failed with code: ${code}`));
            });
        });
    });
}
//# sourceMappingURL=cloud-foundry.js.map